import yaml


def parse(file_path):
    trash_string = ('1CClientBankExchange', 'КонецФайла')
    content = []
    indent_count = 0

    with open(file_path) as f:
        lines = f.readlines()
        for line in lines:
            if [t for t in trash_string if t in line]:
                continue

            line = line.replace('=', ': ')

            if 'Секция' in line:
                if ':' in line:
                    name, value = line.split(': ')
                    line = name + ':\n'

                    if line not in content:
                        content.append('  ' * indent_count + line)

                    line = '  ' * (indent_count) + '- ' + value.replace('\n', ':\n')
                else:
                    line = line.replace('\n', ': \n')

                content.append('    ' * indent_count + line)
                indent_count += 1
            elif 'Конец' in line:
                indent_count -= 1
            else:
                content.append('  ' * indent_count + line)

    content_as_str = ''.join(content)
    return yaml.load(content_as_str, Loader=yaml.FullLoader)


from setuptools import setup, find_packages
from os.path import join, dirname


AUTHOR = "Maxim Prokopenko"
AUTHOR_EMAIL = "maximprokopenko@gmail.com"
NAME = "1c_format"
PACKAGE = '1c_format'
VERSION = '0.1'
URL = 'https://github.com/maximprokopenko/1c_format'


setup(
    name=NAME,
    packages=[PACKAGE],
    version=VERSION,
    long_description=open(join(dirname(__file__), 'README.md')).read(),
    author=AUTHOR,
    author_email=AUTHOR_EMAIL,
    url=URL,
    install_requires=[]
)
